@@ -2,7 +2,7 @@ use std::fs;
 use std::path::PathBuf;
 
 pub fn get_image_paths(path: &str) -> Vec<PathBuf> {
-    static FILE_TYPES: [&str; 3] = ["png", "jpg", "jpeg"];
+    static FILE_TYPES: [&str; 6] = ["png", "jpg", "jpeg", "webp", "bmp", "gif"];
 
     let paths = fs::read_dir(path).unwrap();
     let mut result = vec![];
